@@ -71,27 +71,7 @@ model_extraction_helper <- function(.fit_object){
 
     # * Function Factory ----
     mod_obj_arima <- function(model_fit_type){
-        ar_mod <- if (model_fit_type == "arima"){
-            ar_order <- forecast::arimaorder(fit_object)
-            ar_p <- ar_order[["p"]]
-            ar_d <- ar_order[["d"]]
-            ar_q <- ar_order[["q"]]
-            ar_P <- ar_order[["P"]]
-            ar_D <- ar_order[["D"]]
-            ar_Q <- ar_order[["Q"]]
-            ar_F <- ar_order[["Frequency"]]
-            ar_drift <- tryCatch(
-                {ifelse(fit_object$coef[["drift"]], "with drift", "")}
-                ,error = function(e){e=NULL}
-            )
-            ar_model <- paste0(
-                "ARIMA",
-                "(", ar_p, ",", ar_d, ",", ar_q, ")",
-                "(", ar_P, ",", ar_D, ",", ar_Q, ")",
-                "[", ar_F, "]",
-                " ", ar_drift
-            )
-        }
+        ar_mod <- healthyR.ts::arima_string(fit_object)
         return(ar_mod)
     }
 
